/**********************************************************************/
/*            pro.h                                                   */
/**********************************************************************/

#ifndef _PRO_H
#define _PRO_H

void ini_notation(void);
WORD legal_move(BYTE **,WORD *,WORD *);
void notation_update(int piece, int from, int to);
WORD reg_zug(WORD von,WORD nach);
void rueck_w(WORD,WORD);
void rueck_s(WORD,WORD);
int  move_generator(BYTE **,WORD *,WORD *);
#endif /* _PRO_H */
